pub enum InterfaceName {
Exact(CString),
StartingWith(CString),
}Expand description
Can be used to compare the value loaded by Meta::IifName and Meta::OifName. Please
note that it is faster to check interface index than name.
Variants
Exact(CString)
Interface name must be exactly the value of the CString.
StartingWith(CString)
Interface name must start with the value of the CString.
InterfaceName::StartingWith("eth") will look like eth* when printed and match against
eth0, eth1, …, eth99 and so on.