Rule

Struct Rule 

pub struct Rule<'a> { /* private fields */ }
A nftables firewall rule.

Implementations

Source

impl<'a> Rule<'a>

pub fn new(chain: &'a Chain<'_>) -> Rule<'a>

Creates a new rule object in the given Chain.

pub fn set_position(&mut self, position: u64)

Sets the position of this rule within the chain it lives in. By default a new rule is added to the end of the chain.

pub fn set_handle(&mut self, handle: u64)

pub fn add_expr(&mut self, expr: &impl Expression)

Adds an expression to this rule. Expressions are evaluated from first to last added. As soon as an expression does not match the packet it’s being evaluated for, evaluation stops and the packet is evaluated against the next rule in the chain.

pub fn set_comment<T: AsRef<CStr>>( &mut self, comment: T, ) -> Result<(), &'static str>

Add a comment to this rule.

Returns Err if comment is too large.

pub fn get_chain(&self) -> &Chain<'_>

Returns a reference to the Chain this rule lives in.