pub struct Table { /* private fields */ }Expand description
Abstraction of nftnl_table. The top level container in netfilter. A table has a protocol
family and contain Chains that in turn hold the rules.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn new<T: AsRef<CStr>>(name: T, family: ProtoFamily) -> Table
pub fn new<T: AsRef<CStr>>(name: T, family: ProtoFamily) -> Table
Creates a new table instance with the given name and protocol family.
Sourcepub fn get_family(&self) -> ProtoFamily
pub fn get_family(&self) -> ProtoFamily
Returns the protocol family for this table.