pub struct Rule<'a> { /* private fields */ }Expand description
A nftables firewall rule.
Implementations
Sourceimpl<'a> Rule<'a>
impl<'a> Rule<'a>
Sourcepub fn set_position(&mut self, position: u64)
pub fn set_position(&mut self, position: u64)
Sets the position of this rule within the chain it lives in. By default a new rule is added to the end of the chain.
pub fn set_handle(&mut self, handle: u64)
Sourcepub fn add_expr(&mut self, expr: &impl Expression)
pub fn add_expr(&mut self, expr: &impl Expression)
Adds an expression to this rule. Expressions are evaluated from first to last added. As soon as an expression does not match the packet it’s being evaluated for, evaluation stops and the packet is evaluated against the next rule in the chain.